'use strict'

const gm = require('gm').subClass({ imageMagick: true })
const aws = require('aws-sdk')
const s3 = new aws.S3()

module.exports.convert = (event, context) => {
  const srcBucket = event.Records[0].s3.bucket.name
  const srcKey = event.Records[0].s3.object.key
  const destBucket = srcBucket + '-resized'
  const destKey = 'resized-' + srcKey

  const typeMatch = srcKey.match(/\.([^.]*)$/)
  if (!typeMatch) {
    context.fail('Could not determine the image type')
    return
  }
  const imageType = typeMatch[1]
  if (imageType != 'jpg' && imageType != 'png') {
    context.fail(`Unsupported image type: ${imageType}`)
    return
  }  
  
  s3.getObject({ Bucket: srcBucket, Key: srcKey })
    .promise()
    .then((response) => {
      return new Promise((resolve, reject) => {
        gm(response.Body)
          .resize(100)
          .toBuffer(imageType, (err, buffer) => {
            if (err) {
              reject(err)
              return
            }
            resolve(buffer, response.ContentType)
          })
      })
    })
    .then((buffer, contentType) => {
      return s3.putObject({
        Bucket: destBucket,
        Key: destKey,
        Body: buffer,
        ContentType: contentType
      }).promise()
    })
    .then((res) => context.succeed(res))
    .catch((err) => context.fail(err))
}

